from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="indian_cities",
    version="0.0.5",
    description="Django Indian Cities",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    url="https://github.com/chayandatta/django_indian_cities",
    author="Chayan Datta",
    author_email="chayan.datta1996@gmail.com",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.0",
)



cities = (
    ("Andaman and Nicobar Islands", (("Port Blair", "Port Blair"),)),
    (
        "Andhra Pradesh",
        (
            ("Visakhapatnam", "Visakhapatnam"),
            ("Vijayawada", "Vijayawada"),
            ("Guntur", "Guntur"),
            ("Nellore", "Nellore"),
            ("Kurnool", "Kurnool"),
            ("Rajamahendravaram", "Rajamahendravaram"),
            ("Tirupati", "Tirupati"),
            ("Kadapa", "Kadapa"),
            ("Kakinada", "Kakinada"),
            ("Anantapur", "Anantapur"),
            ("Vizianagaram", "Vizianagaram"),
            ("Eluru", "Eluru"),
            ("Ongole", "Ongole"),
            ("Nandyal", "Nandyal"),
            ("Machilipatnam", "Machilipatnam"),
            ("Adoni", "Adoni"),
            ("Tenali", "Tenali"),
            ("Proddatur", "Proddatur"),
            ("Chittoor", "Chittoor"),
            ("Hindupur", "Hindupur"),
            ("Bhimavaram", "Bhimavaram"),
            ("Madanapalle", "Madanapalle"),
            ("Guntakal", "Guntakal"),
            ("Srikakulam", "Srikakulam"),
            ("Dharmavaram", "Dharmavaram"),
            ("Gudivada", "Gudivada"),
            ("Narasaraopet", "Narasaraopet"),
            ("Tadipatri", "Tadipatri"),
            ("Tadepalligudem", "Tadepalligudem"),
            ("Amaravati", "Amaravati"),
            ("Chilakaluripet", "Chilakaluripet"),
        ),
    ),
    (
        "Bihar",
        (
            ("Patna", "Patna"),
            ("Gaya", "Gaya"),
            ("Bhagalpur", "Bhagalpur"),
            ("Muzaffarpur", "Muzaffarpur"),
            ("Purnia", "Purnia"),
            ("Darbhanga", "Darbhanga"),
            ("Bihar Sharif", "Bihar Sharif"),
            ("Arrah", "Arrah"),
            ("Begusarai", "Begusarai"),
            ("Katihar", "Katihar"),
            ("Munger", "Munger"),
            ("Chhapra", "Chhapra"),
            ("Bettiah", "Bettiah"),
            ("Saharsa", "Saharsa"),
            ("Hajipur", "Hajipur"),
            ("Sasaram", "Sasaram"),
            ("Dehri", "Dehri"),
            ("Siwan", "Siwan"),
            ("Motihari", "Motihari"),
            ("Nawada", "Nawada"),
            ("Bagaha", "Bagaha"),
            ("Buxar", "Buxar"),
            ("Kishanganj", "Kishanganj"),
            ("Sitamarhi", "Sitamarhi"),
            ("Jamalpur", "Jamalpur"),
            ("Jehanabad", "Jehanabad"),
            ("Aurangabad", "Aurangabad"),
            ("Lakhisarai", "Lakhisarai"),
        ),
    ),
    ("Chandigarh", (("Chandigarh", "Chandigarh"),),),
    (
        "Chhattisgarh",
        (
            ("Raipur", "Raipur"),
            ("Durg", "Durg"),
            ("Naya Raipur", "Naya Raipur"),
            ("Korba", "Korba"),
            ("Bilaspur", "Bilaspur"),
            ("Rajnandgaon", "Rajnandgaon"),
            ("Pakhanjore", "Pakhanjore"),
            ("Jagdalpur", "Jagdalpur"),
            ("Ambikapur", "Ambikapur"),
            ("Chirmiri", "Chirmiri"),
            ("Dhamtari", "Dhamtari"),
            ("Raigarh", "Raigarh"),
            ("Mahasamund", "Mahasamund"),
        ),
    ),
    ("Daman and Diu", (("Daman", "Daman"),),),
    ("Delhi", (("Delhi", "Delhi"),),),
    ("Dadra and Nagar Haveli", (("Silvassa", "Silvassa"),),),
    (
        "Goa",
        (
            ("Panaji", "Panaji"),
            ("Vasco", "Vasco"),
            ("Mormugao", "Mormugao"),
            ("Margao", "Margao"),
        ),
    ),
    (
        "Gujarat",
        (
            ("Ahmedabad", "Ahmedabad"),
            ("Surat", "Surat"),
            ("Vadodara", "Vadodara"),
            ("Rajkot", "Rajkot"),
            ("Bhavnagar", "Bhavnagar"),
            ("Jamnagar", "Jamnagar"),
            ("Junagadh", "Junagadh"),
            ("Gandhidham", "Gandhidham"),
            ("Nadiad", "Nadiad"),
            ("Gandhinagar", "Gandhinagar"),
            ("Anand", "Anand"),
            ("Morbi", "Morbi"),
            ("Khambhat", "Khambhat"),
            ("Surendranagar", "Surendranagar"),
            ("Bharuch", "Bharuch"),
            ("Vapi", "Vapi"),
            ("Navsari", "Navsari"),
            ("Veraval", "Veraval"),
            ("Porbandar", "Porbandar"),
            ("Godhra", "Godhra"),
            ("Bhuj", "Bhuj"),
            ("Ankleshwar", "Ankleshwar"),
            ("Botad", "Botad"),
            ("Patan", "Patan"),
            ("Palanpur", "Palanpur"),
            ("Dahod", "Dahod"),
            ("Jetpur", "Jetpur"),
            ("Valsad", "Valsad"),
            ("Kalol", "Kalol"),
            ("Gondal", "Gondal"),
            ("Deesa", "Deesa"),
            ("Amreli", "Amreli"),
            ("Amreli", "Amreli"),
            ("Mahuva", "Mahuva"),
            ("Mehsana", "Mehsana"),
        ),
    ),
    ("Himachal Pradesh", (("Shimla", "Shimla"),),),
    (
        "Haryana",
        (
            ("Faridabad", "Faridabad"),
            ("Gurgaon", "Gurgaon"),
            ("Panipat", "Panipat"),
            ("Ambala", "Ambala"),
            ("Yamunanagar", "Yamunanagar"),
            ("Rohtak", "Rohtak"),
            ("Hisar", "Hisar"),
            ("Karnal", "Karnal"),
            ("Sonipat", "Sonipat"),
            ("Panchkula", "Panchkula"),
            ("Bhiwani", "Bhiwani"),
            ("Sirsa", "Sirsa"),
            ("Bahadurgarh", "Bahadurgarh"),
            ("Jind", "Jind"),
            ("Thanesar", "Thanesar"),
            ("Kaithal", "Kaithal"),
            ("Rewari", "Rewari"),
            ("Palwal", "Palwal"),
        ),
    ),
    (
        "Jharkhand",
        (
            ("Jamshedpur", "Jamshedpur"),
            ("Dhanbad", "Dhanbad"),
            ("Ranchi", "Ranchi"),
            ("Bokaro Steel City", "Bokaro Steel City"),
            ("Deoghar", "Deoghar"),
            ("Phusro", "Phusro"),
            ("Hazaribagh", "Hazaribagh"),
            ("Giridih", "Giridih"),
            ("Ramgarh", "Ramgarh"),
            ("Medininagar", "Medininagar"),
            ("Chirkunda", "Chirkunda"),
            ("Jhumri Telaiya", "Jhumri Telaiya"),
            ("Sahibganj", "Sahibganj"),
        ),
    ),
    (
        "Jammu and Kashmir",
        (("Srinagar", "Srinagar"), ("Jammu", "Jammu"), ("Anantnag", "Anantnag"),),
    ),
    (
        "Karnataka",
        (
            ("Bengaluru", "Bengaluru"),
            ("Hubli", "Hubli"),
            ("Mysore", "Mysore"),
            ("Gulbarga", "Gulbarga"),
            ("Mangalore", "Mangalore"),
            ("Belgaum", "Belgaum"),
            ("Davangere", "Davangere"),
            ("Bellary", "Bellary"),
            ("Bijapur", "Bijapur"),
            ("Shimoga", "Shimoga"),
            ("Tumkur", "Tumkur"),
            ("Raichur", "Raichur"),
            ("Bidar", "Bidar"),
            ("Hospet", "Hospet"),
            ("Hassan", "Hassan"),
            ("Gadag", "Gadag"),
            ("Udupi", "Udupi"),
            ("Robertsonpet", "Robertsonpet"),
            ("Bhadravati", "Bhadravati"),
            ("Chitradurga", "Chitradurga"),
            ("Harihar", "Harihar"),
            ("Kolar", "Kolar"),
            ("Mandya", "Mandya"),
            ("Chikkamagallooru", "Chikkamagallooru"),
            ("Chikmagalur", "Chikmagalur"),
            ("Gangawati", "Gangawati"),
            ("Ranebennuru", "Ranebennuru"),
            ("Ramanagara", "Ramanagara"),
            ("Bagalkot", "Bagalkot"),
        ),
    ),
    (
        "Kerala",
        (
            ("Thiruvananthapuram", "Thiruvananthapuram"),
            ("Kochi", "Kochi"),
            ("Calicut", "Calicut"),
            ("Kollam", "Kollam"),
            ("Thrissur", "Thrissur"),
            ("Kannur", "Kannur"),
            ("Kasaragod", "Kasaragod"),
            ("Alappuzha", "Alappuzha"),
            ("Alappuzha", "Alappuzha"),
            ("Palakkad", "Palakkad"),
            ("Kottayam", "Kottayam"),
            ("Kothamangalam", "Kothamangalam"),
            ("Malappuram", "Malappuram"),
            ("Manjeri", "Manjeri"),
            ("Thalassery", "Thalassery"),
            ("Ponnani", "Ponnani"),
        ),
    ),
    ("Lakshadweep", (("Kavaratti", "Kavaratti"),),),
    (
        "Maharashtra",
        (
            ("Mumbai", "Mumbai"),
            ("Pune", "Pune"),
            ("Nagpur", "Nagpur"),
            ("Nashik", "Nashik"),
            ("Pimpri-Chinchwad", "Pimpri-Chinchwad"),
            ("Aurangabad", "Aurangabad"),
            ("Solapur", "Solapur"),
            ("Bhiwandi", "Bhiwandi"),
            ("Amravati", "Amravati"),
            ("Nanded", "Nanded"),
            ("Kolhapur", "Kolhapur"),
            ("Sangli-Miraj-Kupwad", "Sangli-Miraj-Kupwad"),
            ("Jalgaon", "Jalgaon"),
            ("Akola", "Akola"),
            ("Latur", "Latur"),
            ("Malegaon", "Malegaon"),
            ("Dhule", "Dhule"),
            ("Ahmednagar", "Ahmednagar"),
            ("Nandurbar", "Nandurbar"),
            ("Ichalkaranji", "Ichalkaranji"),
            ("Chandrapur", "Chandrapur"),
            ("Jalna", "Jalna"),
            ("Parbhani", "Parbhani"),
            ("Bhusawal", "Bhusawal"),
            ("Satara", "Satara"),
            ("Beed", "Beed"),
            ("Pandharpur", "Pandharpur"),
            ("Yavatmal", "Yavatmal"),
            ("Kamptee", "Kamptee"),
            ("Gondia", "Gondia"),
            ("Achalpur", "Achalpur"),
            ("Osmanabad", "Osmanabad"),
            ("Hinganghat", "Hinganghat"),
            ("Wardha", "Wardha"),
            ("Barshi", "Barshi"),
            ("Chalisgaon", "Chalisgaon"),
            ("Amalner", "Amalner"),
            ("Khamgaon", "Khamgaon"),
            ("Akot", "Akot"),
            ("Udgir", "Udgir"),
            ("Bhandara", "Bhandara"),
            ("Parli", "Parli"),
        ),
    ),
    ("Meghalaya", (("Shillong", "Shillong"),),),
    ("Manipur", (("Imphal", "Imphal"),),),
    (
        "Madhya Pradesh",
        (
            ("Indore", "Indore"),
            ("Bhopal", "Bhopal"),
            ("Jabalpur", "Jabalpur"),
            ("Gwalior", "Gwalior"),
            ("Ujjain", "Ujjain"),
            ("Sagar", "Sagar"),
            ("Dewas", "Dewas"),
            ("Satna", "Satna"),
            ("Ratlam", "Ratlam"),
            ("Rewa", "Rewa"),
            ("Katni", "Katni"),
            ("Singrauli", "Singrauli"),
            ("Burhanpur", "Burhanpur"),
            ("Khandwa", "Khandwa"),
            ("Morena", "Morena"),
            ("Bhind", "Bhind"),
            ("Chhindwara", "Chhindwara"),
            ("Guna", "Guna"),
            ("Shivpuri", "Shivpuri"),
            ("Vidisha", "Vidisha"),
            ("Chhatarpur", "Chhatarpur"),
            ("Damoh", "Damoh"),
            ("Mandsaur", "Mandsaur"),
            ("Khargone", "Khargone"),
            ("Neemuch", "Neemuch"),
            ("Pithampur", "Pithampur"),
            ("Hoshangabad", "Hoshangabad"),
            ("Itarsi", "Itarsi"),
            ("Sehore", "Sehore"),
            ("Betul", "Betul"),
            ("Seoni", "Seoni"),
            ("Datia", "Datia"),
            ("Nagda", "Nagda"),
            ("Dhanpuri", "Dhanpuri"),
            ("Dhar", "Dhar"),
            ("Balaghat", "Balaghat"),
        ),
    ),
    ("Mizoram", (("Aizawl", "Aizawl"),),),
    ("Nagaland", (("Dimapur", "Dimapur"), ("Kohima", "Kohima"),),),
    (
        "Odisha",
        (
            ("Bhubaneswar", "Bhubaneswar"),
            ("Cuttack", "Cuttack"),
            ("Rourkela", "Rourkela"),
            ("Berhampur", "Berhampur"),
            ("Sambalpur", "Sambalpur"),
            ("Puri", "Puri"),
            ("Balasore", "Balasore"),
            ("Bhadrak", "Bhadrak"),
            ("Baripada", "Baripada"),
            ("Balangir", "Balangir"),
            ("Jharsuguda", "Jharsuguda"),
            ("Jeypore", "Jeypore"),
        ),
    ),
    (
        "Punjab",
        (
            ("Ludhiana", "Ludhiana"),
            ("Amritsar", "Amritsar"),
            ("Jalandhar", "Jalandhar"),
            ("Patiala", "Patiala"),
            ("Bathinda", "Bathinda"),
            ("Hoshiarpur", "Hoshiarpur"),
            ("Batala", "Batala"),
            ("Mohali", "Mohali"),
            ("Abohar", "Abohar"),
            ("Pathankot", "Pathankot"),
            ("Moga", "Moga"),
            ("Malerkotla", "Malerkotla"),
            ("Khanna", "Khanna"),
            ("Muktasar", "Muktasar"),
            ("Barnala", "Barnala"),
            ("Firozpur", "Firozpur"),
            ("Kapurthala", "Kapurthala"),
            ("Phagwara", "Phagwara"),
            ("Zirakpur", "Zirakpur"),
            ("Rajpura", "Rajpura"),
        ),
    ),
    (
        "Puducherry",
        (
            ("Pondicherry", "Pondicherry"),
            ("Ozhukarai", "Ozhukarai"),
            ("Karaikal", "Karaikal"),
        ),
    ),
    (
        "Rajasthan",
        (
            ("Jaipur", "Jaipur"),
            ("Jodhpur", "Jodhpur"),
            ("Kota", "Kota"),
            ("Bikaner", "Bikaner"),
            ("Ajmer", "Ajmer"),
            ("Udaipur", "Udaipur"),
            ("Bhilwara", "Bhilwara"),
            ("Alwar", "Alwar"),
            ("Bharatpur", "Bharatpur"),
            ("Sri Ganganagar", "Sri Ganganagar"),
            ("Sikar", "Sikar"),
            ("Pali", "Pali"),
            ("Barmer", "Barmer"),
            ("Tonk", "Tonk"),
            ("Kishangarh", "Kishangarh"),
            ("Chittorgarh", "Chittorgarh"),
            ("Beawar", "Beawar"),
            ("Hanumangarh", "Hanumangarh"),
            ("Dholpur", "Dholpur"),
            ("Gangapur", "Gangapur"),
            ("Sawai Madhopur", "Sawai Madhopur"),
            ("Churu", "Churu"),
            ("Baran", "Baran"),
            ("Makrana", "Makrana"),
            ("Nagaur", "Nagaur"),
            ("Hindaun", "Hindaun"),
            ("Bhiwadi", "Bhiwadi"),
            ("Bundi", "Bundi"),
            ("Sujangarh", "Sujangarh"),
            ("Jhunjhunu", "Jhunjhunu"),
            ("Banswara", "Banswara"),
            ("Sardarshahar", "Sardarshahar"),
            ("Fatehpur", "Fatehpur"),
            ("Dausa", "Dausa"),
            ("Karauli", "Karauli"),
        ),
    ),
    ("Sikkim", (("Gangtok", "Gangtok"),),),
    (
        "Telangana",
        (
            ("Hyderabad", "Hyderabad"),
            ("Warangal", "Warangal"),
            ("Nizamabad", "Nizamabad"),
            ("Karimnagar", "Karimnagar"),
            ("Ramagundam", "Ramagundam"),
            ("Khammam", "Khammam"),
            ("Mahbubnagar", "Mahbubnagar"),
            ("Nalgonda", "Nalgonda"),
            ("Adilabad", "Adilabad"),
            ("Siddipet", "Siddipet"),
            ("Suryapet", "Suryapet"),
            ("Miryalaguda", "Miryalaguda"),
            ("Jagtial", "Jagtial"),
            ("Mancherial", "Mancherial"),
            ("Kothagudem", "Kothagudem"),
        ),
    ),
    (
        "Tamil Nadu",
        (
            ("Chennai", "Chennai"),
            ("Coimbatore", "Coimbatore"),
            ("Madurai", "Madurai"),
            ("Tiruchirappalli", "Tiruchirappalli"),
            ("Tirupur", "Tirupur"),
            ("Salem", "Salem"),
            ("Erode", "Erode"),
            ("Tirunelveli", "Tirunelveli"),
            ("Vellore", "Vellore"),
            ("Tuticorin", "Tuticorin"),
            ("Gudiyatham", "Gudiyatham"),
            ("Nagercoil", "Nagercoil"),
            ("Thanjavur", "Thanjavur"),
            ("Dindigul", "Dindigul"),
            ("Vaniyambadi", "Vaniyambadi"),
            ("Cuddalore", "Cuddalore"),
            ("Komarapalayam", "Komarapalayam"),
            ("Kanchipuram", "Kanchipuram"),
            ("Ambur", "Ambur"),
            ("Tiruvannamalai", "Tiruvannamalai"),
            ("Pudukkottai", "Pudukkottai"),
            ("Kumbakonam", "Kumbakonam"),
            ("Rajapalayam", "Rajapalayam"),
            ("Hosur", "Hosur"),
            ("Karaikudi", "Karaikudi"),
            ("Neyveli", "Neyveli"),
            ("Nagapattinam", "Nagapattinam"),
            ("Viluppuram", "Viluppuram"),
            ("Paramakudi", "Paramakudi"),
            ("Tiruchengode", "Tiruchengode"),
            ("Kovilpatti", "Kovilpatti"),
            ("Theni-Allinagaram", "Theni-Allinagaram"),
            ("Kadayanallur", "Kadayanallur"),
            ("Pollachi", "Pollachi"),
            ("Ooty", "Ooty"),
        ),
    ),
    ("Tripura", (("Agartala", "Agartala"),),),
    (
        "Uttar Pradesh",
        (
            ("Kanpur", "Kanpur"),
            ("Lucknow", "Lucknow"),
            ("Ghaziabad", "Ghaziabad"),
            ("Agra", "Agra"),
            ("Varanasi", "Varanasi"),
            ("Meerut", "Meerut"),
            ("Allahabad", "Allahabad"),
            ("Bareilly", "Bareilly"),
            ("Aligarh", "Aligarh"),
            ("Moradabad", "Moradabad"),
            ("Saharanpur", "Saharanpur"),
            ("Gorakhpur", "Gorakhpur"),
            ("Faizabad", "Faizabad"),
            ("Firozabad", "Firozabad"),
            ("Jhansi", "Jhansi"),
            ("Muzaffarnagar", "Muzaffarnagar"),
            ("Mathura", "Mathura"),
            ("Budaun", "Budaun"),
            ("Rampur", "Rampur"),
            ("Shahjahanpur", "Shahjahanpur"),
            ("Farrukhabad", "Farrukhabad"),
            ("Mau", "Mau"),
            ("Hapur", "Hapur"),
            ("Noida", "Noida"),
            ("Etawah", "Etawah"),
            ("Mirzapur", "Mirzapur"),
            ("Bulandshahr", "Bulandshahr"),
            ("Sambhal", "Sambhal"),
            ("Amroha", "Amroha"),
            ("Hardoi", "Hardoi"),
            ("Fatehpur", "Fatehpur"),
            ("Raebareli", "Raebareli"),
            ("Orai", "Orai"),
            ("Sitapur", "Sitapur"),
            ("Bahraich", "Bahraich"),
            ("Modinagar", "Modinagar"),
            ("Unnao", "Unnao"),
            ("Jaunpur", "Jaunpur"),
            ("Lakhimpur", "Lakhimpur"),
            ("Hathras", "Hathras"),
            ("Banda", "Banda"),
            ("Pilibhit", "Pilibhit"),
            ("Barabanki", "Barabanki"),
            ("Mughalsarai", "Mughalsarai"),
            ("Khurja", "Khurja"),
            ("Gonda", "Gonda"),
            ("Mainpuri", "Mainpuri"),
            ("Lalitpur", "Lalitpur"),
            ("Etah", "Etah"),
            ("Deoria", "Deoria"),
            ("Ujhani", "Ujhani"),
            ("Ghazipur", "Ghazipur"),
            ("Sultanpur", "Sultanpur"),
            ("Azamgarh", "Azamgarh"),
            ("Bijnor", "Bijnor"),
            ("Sahaswan", "Sahaswan"),
            ("Basti", "Basti"),
            ("Chandausi", "Chandausi"),
            ("Akbarpur", "Akbarpur"),
            ("Ballia", "Ballia"),
            ("Mubarakpur", "Mubarakpur"),
            ("Tanda", "Tanda"),
            ("Greater Noida", "Greater Noida"),
            ("Shikohabad", "Shikohabad"),
            ("Shamli", "Shamli"),
            ("Baraut", "Baraut"),
            ("Khair", "Khair"),
            ("Kasganj", "Kasganj"),
            ("Auraiya", "Auraiya"),
            ("Khatauli", "Khatauli"),
            ("Deoband", "Deoband"),
            ("Nagina", "Nagina"),
            ("Mahoba", "Mahoba"),
            ("Muradnagar", "Muradnagar"),
            ("Bhadohi", "Bhadohi"),
            ("Dadri", "Dadri"),
            ("Pratapgarh", "Pratapgarh"),
            ("Najibabad", "Najibabad"),
        ),
    ),
    (
        "Uttarakhand",
        (
            ("Dehradun", "Dehradun"),
            ("Haridwar", "Haridwar"),
            ("Roorkee", "Roorkee"),
            ("Haldwani", "Haldwani"),
            ("Rudrapur", "Rudrapur"),
            ("Kashipur", "Kashipur"),
            ("Rishikesh", "Rishikesh"),
        ),
    ),
    (
        "West Bengal",
        (
            ("Kolkata", "Kolkata"),
            ("Asansol", "Asansol"),
            ("Siliguri", "Siliguri"),
            ("Durgapur", "Durgapur"),
            ("Bardhaman", "Bardhaman"),
            ("Malda", "Malda"),
            ("Baharampur", "Baharampur"),
            ("Habra", "Habra"),
            ("Jalpaiguri", "Jalpaiguri"),
            ("Kharagpur", "Kharagpur"),
            ("Shantipur", "Shantipur"),
            ("Dankuni", "Dankuni"),
            ("Dhulian", "Dhulian"),
            ("Ranaghat", "Ranaghat"),
            ("Haldia", "Haldia"),
            ("Raiganj", "Raiganj"),
            ("Krishnanagar", "Krishnanagar"),
            ("Nabadwip", "Nabadwip"),
            ("Midnapore", "Midnapore"),
            ("Balurghat", "Balurghat"),
            ("Basirhat", "Basirhat"),
            ("Bankura", "Bankura"),
            ("Chakdaha", "Chakdaha"),
            ("Darjeeling", "Darjeeling"),
            ("Alipurduar", "Alipurduar"),
            ("Purulia", "Purulia"),
            ("Jangipur", "Jangipur"),
            ("Bangaon", "Bangaon"),
            ("Cooch Behar", "Cooch Behar"),
            ("Bolpur", "Bolpur"),
            ("Kanthi", "Kanthi"),
        ),
    ),
)
